@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import requests
 import slumber
 
@@ -20,8 +22,9 @@ class API(object):
         session = requests.Session()
 
         if self.auth_token:
+            # HTTP headers must always be ISO-8859-1 encoded
             session.headers.update({
-                'X-Auth-Token': self.auth_token
+                'X-Auth-Token': self.auth_token.encode('latin1')
             })
 
         if not self.verify_ssl:
@@ -43,3 +46,4 @@ class API(object):
 
 from .api_account import AccountAPI
 from .api_compute import ComputeAPI
+from .api_metadata import MetadataAPI
